# 背面消隐插件
require 'sketchup.rb'

# 创建一个命名空间，避免与其他插件冲突
module BackfaceHider

  # 创建一个命令，用于执行插件的功能
  def self.create_command
    # 创建一个命令对象，设置名称、提示和图标
  	path = Sketchup.find_support_file("Plugins/backfaces-hide")
    cmd = UI::Command.new("背面消隐-SUCJ.ME") {
      self.hide_backfaces
    }
    cmd.large_icon = File.join(path,"bmxy-36.png")
	cmd.small_icon = File.join(path,"bmxy-24.png")
    cmd.tooltip = "背面消隐-SUCJ.ME"
    cmd.status_bar_text = "将选中的面背面设置为全透明材质，以达到类似3DS MAX里的背面消隐效果"
    cmd.set_validation_proc {
      # 只有当选择集中有面时，命令才可用
      if Sketchup.active_model.selection.grep(Sketchup::Face).empty?
        MF_GRAYED
      else
        MF_ENABLED
      end
    }
    # 返回命令对象
    cmd
  end

  # 创建一个方法，用于实现插件的功能
  def self.hide_backfaces
    # 获取当前模型和选择集
    model = Sketchup.active_model
    selection = model.selection
    # 开始一个操作，便于撤销
    model.start_operation("背面消隐-SUCJ.ME", true)
    # 遍历选择集中的所有面
    selection.grep(Sketchup::Face).each { |face|
      # 获取或创建一个名为hide的材质，设置为白色，透明度100%
      material = model.materials["hide"] || model.materials.add("hide")
      material.color = Sketchup::Color.new(255, 255, 255)
      material.alpha = 0.0
      # 将面的背面材质设置为hide
      face.back_material = material
    }
    # 结束操作
    model.commit_operation
  end

  # 创建一个工具栏，添加插件的命令
  def self.create_toolbar
    # 创建一个工具栏对象，设置名称
    toolbar = UI::Toolbar.new("背面消隐-SUCJ.ME")
    # 向工具栏中添加插件的命令
    toolbar.add_item(self.create_command)
    # 显示工具栏
    toolbar.show
  end

  # 当插件被加载时，调用创建工具栏的方法
  self.create_toolbar

end
